==> haskell-crypton-x509-store-1.6.9-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.9
visibility:           public
id:                   crypton-x509-store-1.6.9-GUEyMfoSIau7bjAg2W1fOj
key:                  crypton-x509-store-1.6.9-GUEyMfoSIau7bjAg2W1fOj
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  e0809e203b8020545996315a35e64529
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.9-GUEyMfoSIau7bjAg2W1fOj
depends:
    asn1-encoding-0.9.6-RO0MtPvMueEUvZE3gjiU7
    asn1-types-0.3.4-JpoT0OUYh9CEK2ZbjJrThT base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-0.34-4bqmaNpvFyKLqEcEOMaVvT
    crypton-x509-1.7.6-CJniK3OXDXpCi7f6bVHBHR directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-JJ6WzfBRXi6GfNaCIp5TrY

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-store-1.6.9-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.9
visibility:           public
id:                   crypton-x509-store-1.6.9-Fk1HDOb3v0A7vmbxIab90J
key:                  crypton-x509-store-1.6.9-Fk1HDOb3v0A7vmbxIab90J
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  a091e987074e562f797038e3aff924d2
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.9-Fk1HDOb3v0A7vmbxIab90J
depends:
    asn1-encoding-0.9.6-3x7ZgPhBJsG1syz5zuvxo6
    asn1-types-0.3.4-9jRq3hQWhveGH07jdc4YHi base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-0.34-nIgIaEefoJJHFVCyLJMup
    crypton-x509-1.7.6-DbKkMUASGyO8NQuIKJraym directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-F1xpDUEHKsM3Ok5PlpMmf5

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
